# Netlify Plugin - Minify JS

This plugin adds the ability to minify the JS generated by your build.

Note: Many SSGs support this as part of their own process so this might not always be necessary.

This plugin is agnostic to the tool being used to generate the markup, and acts purely on the markup it finds in `.js` files in the publish folder which [Netlify](https://www.netlify.com) is preparing to deploy to its CDN following a successful build.

## Installation

To include this plugin in your site deployment, use the file-based installation:

### File-based installation

#### 1. Add the plugin as a dependency

```bash

# Add the plugin as a dependency of your build
npm i -D netlify-plugin-minify-js

```


#### 2. Add the plugin and its options to your netlify.toml

You can choose which [deploy contexts](https://docs.netlify.com/site-deploys/overview/?utm_source=github&utm_medium=plugin-htmlminfier-pnh&utm_campaign=devex#deploy-contexts) will include the HTML minification with the `targets` option.

You can use the default options for the minification or use `[plugins.inputs.minifierOptions]` to pass options to the minifier.

```toml

# Config for the Netlify Build Plugin: netlify-plugin-minify-js
[[plugins]]
  package = "netlify-plugin-minify-js"

  # Specify which deploy contexts we'll minify JS in.
  # Supports any Deploy Contexts available in Netlify.
  # https://docs.netlify.com/site-deploys/overview/#deploy-contexts
  [plugins.inputs]
    contexts = [
      'production',
      'branch-deploy',
      'deploy-preview'
    ]

  # Optionally, override the default options for the minification
  # https://github.com/kangax/html-minifier#options-quick-reference
  [plugins.inputs.minifierOptions]
    warnings = true
```